@@ -3,7 +3,7 @@ package SQL::Statement::Function;
 require SQL::Statement::Term;
 @ISA = qw(SQL::Statement::Term);
 
-our $VERSION = '1.22';
+our $VERSION = '1.24';
 
 =pod
 
@@ -147,7 +147,7 @@ package SQL::Statement::Function::NumericEval;
 
 use vars qw(@ISA);
 
-use Params::Util qw(_NUMBER);
+use Params::Util qw(_NUMBER _INSTANCE);
 
 @ISA = qw(SQL::Statement::Function);
 
@@ -191,7 +191,7 @@ Returns the result of the evaluated expression.
 
 sub new
 {
-    my ($class,$owner,$expr,$params) = @_;
+    my ( $class, $owner, $expr, $params ) = @_;
 
     my $self = $class->SUPER::new($owner);
 
@@ -284,9 +284,9 @@ Returns the trimmed value of first parameter argument.
 
 sub new
 {
-    my ($class, $owner, $spec, $char, $params ) = @_;
-    $spec   ||= 'BOTH';
-    $char   ||= ' ';
+    my ( $class, $owner, $spec, $char, $params ) = @_;
+    $spec ||= 'BOTH';
+    $char ||= ' ';
 
     my $self = $class->SUPER::new($owner);
 
@@ -378,7 +378,7 @@ Returns the extracted sub-string value from first parameter argument.
 
 sub new
 {
-    my ($class,$owner,$start,$length,$params) = @_;
+    my ( $class, $owner, $start, $length, $params ) = @_;
 
     my $self = $class->SUPER::new($owner);
 
@@ -441,7 +441,7 @@ Returns the concatenated string composed of the parameter values.
 
 sub new
 {
-    my ($class,$owner,$params ) = @_;
+    my ( $class, $owner, $params ) = @_;
 
     my $self = $class->SUPER::new($owner);
 
@@ -462,7 +462,7 @@ sub value($)
 
 =head1 AUTHOR AND COPYRIGHT
 
-Copyright (c) 2009 by Jens Rehsack: rehsackATcpan.org
+Copyright (c) 2009,2010 by Jens Rehsack: rehsackATcpan.org
 
 All rights reserved.
 
